PROGRAM_NAME='SONY, MDS-B6P, RS-232, BASIC, 2-98, AMX'
(*   DATE:05/20/99    TIME:16:31:48    *)
(***********************************************************)
(* The following code block is provided as a guide to      *)
(* programming the device(s) listed above. This is a       *)
(* sample only, and will most likely require modification  *)
(* to be integrated into a master program.                 *)
(*                                                         *)
(* Device-specific protocols should be obtained directly   *)
(* from the equipment manufacturer to ensure compliance    *)
(* with the most current versions. Within the limits       *)
(* imposed by any non-disclosure agreements, AMX will      *)
(* provide protocols upon request.                         *)
(*                                                         *)
(* If further programming assistance is required, please   *)
(* contact your AMX customer support team.                 *)
(*                                                         *)
(***********************************************************)
(* System Type :  AXB-EM232 v3.730                         *)
(***********************************************************)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

MINI_DISC   = 2         (* 232 PORT 2 : 9600,8,N,1 *)
                        (* Baud,Data,Parity AND Stop bits are
                           Configurable from the Unit itself *)
TP          = 128
(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(* These Constants Used for Transport Controls *)
#IF_NOT_DEFINED SYSCALL_MISC
#DEFINE SYSCALL_MISC
NO_BUTTON   = 0
NO_FUNCTION = 256
#END_IF

#IF_NOT_DEFINED XPORT_CONST
#DEFINE XPORT_CONST
PLAY    = 1
STOP    = 2
PAUSE   = 3
FFWD    = 4
REW     = 5
SFWD    = 6
SREV    = 7
REC     = 8
#END_IF

#IF_NOT_DEFINED FEEDBACK_CONST
#DEFINE FEEDBACK_CONST
PLAY_FB    = 241
STOP_FB    = 242
PAUSE_FB   = 243
FFWD_FB    = 244
REW_FB     = 245
SFWD_FB    = 246
SREV_FB    = 247
REC_FB     = 248
#END_IF

(* button feedback flag *)
#IF_NOT_DEFINED MDP1_DEFEAT_FEEDBACK
MDP1_DEFEAT_FEEDBACK = 0
#END_IF


(* Mini Disc Constants *)

CUE_STANDBY   = 44
CUE           = 45
TRACK_FIND    = 46
TRACK_ORDER   = 47
CLEAR_PGM     = 48
EJECT         = 49

(* Mode Settings *)
TIMER_PLAY    = 1
AUTO_PAUSE    = 2
EOM           = 3
AUTO_DISP     = 4
PREVENT       = 5

(* Status Detect *)
MODEL_NAME    = '8F'
POWER_SENSE   = '74'
DISC_IN       = 'D6'
TOTAL_TRACK   = 'DD'
OPER_STATUS   = 'D0'
PGM_NUMBER    = 'D5'
NEXT_TRACK    = '76'
OEM_SETTING   = '76'
ERR_MSG       = '70'
CAUTION_OUT   = '71'
ILLEGAL_MSG   = '72'


INFO_RETURN   = 1
TRACK_NUM     = 2
PGM_TRACK_NUM = 3
MULTI_ACCESS_PRESET = 4
NEXT_AMS      = 5
PGM_MODE      = 6
MULTI_ACCESS_SLOT   = 7
AUT_RETURN    = 8
AUTO_DISPLAY  = 9
EOM_TIME      = 10
TIMER_PLAY_RETURN   = 11
PLAY_MODE     = 12
REPEAT_MODE   = 13
KILL_MODE     = 14
SWITCH_MODE   = 15
MECHA_STATUS  = 16
TRACK_NUM_STATUS    = 17
DISC_STATUS   = 18
DISC_NAME     = 19
TRACK_TIME    = 20
TRACK_NAME    = 21
CURRENT_TRACK_REMAIN= 22
TOTAL_TRACK_TIME    = 23
HOUR_METER_RETURN   = 24
ERROR_SENSE_RETURN  = 25
CAUTION_SENSOR      = 26
GET_TRACK_TIME      = 27

(* Time Information *)
TOTAL_TIME    = 1
ELAPSED_TIME  = 2
REMAINING_TIME= 3

(* Character Information *)
DISC_TITLE    = 1
TRACK_TITLE   = 2

(* Editing Functions *)
TRACK_ERASE   = 1
ALL_ERASE     = 2
MDP_DIVIDE    = 3
MDP_COMBINE   = 4
MDP_MOVE      = 5

(* Other *)
CR            = $0D
LF            = $0A
(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

TRK
STR[30]
STR_LEN[2]

DEBUG_MSG
MINI_DISC_BUFF[100]
MINI_DISC_CMD[20]
DATA[50]
DATA1[2]
DATA2[2]
DATA3[2]
DATA4[2]
CMD_LEN
CMD[2]
LINE_FEED
CUR_TRACK
CUR_TRACK_NAME[255][100]
CUR_DISC_NAME[100]
(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)
DEFINE_CALL 'Mini Disc Function' (MDP,FUNC_TYPE,FUNC,DT)
LOCAL_VAR
     DIVIDE_MODE[2]
     COMBINE_MODE[2]
     PGM_AREA[2]
     D1[2]
     D2[2]
     D3[2]
     D4[2]
     TITLE[100]
     LEN
{
   SELECT
   {
      ACTIVE (FUNC_TYPE = 1) :   (* Basic Operations *)
      {
         SELECT
         {
           ACTIVE (FUNC = PLAY) :
              SEND_STRING MDP,"LF,'211',CR"
           ACTIVE (FUNC = STOP) :
              SEND_STRING MDP,"LF,'41000',CR"
           ACTIVE (FUNC = PAUSE):
           {
              IF ([MDP,241])
                SEND_STRING MDP,"LF,'41002',CR"
              ELSE IF ([MDP,243])
                SEND_STRING MDP,"LF,'41003',CR"
           }
           ACTIVE (FUNC = FFWD) :
           {
              SEND_STRING MDP,"LF,'41A00',CR"
           }
           ACTIVE (FUNC = REW)  :
           {
              SEND_STRING MDP,"LF,'41A01',CR"
           }
           ACTIVE (FUNC = SFWD) :
           {
              SEND_STRING MDP,"LF,'41602',CR"
           }
           ACTIVE (FUNC = SREV) :
           {
              SEND_STRING MDP,"LF,'4160A',CR"
           }
           ACTIVE (FUNC = TRACK_FIND) :
           {
              (* DT = TRACK TO LOCATE *)
              SEND_STRING MDP,"LF,'423',ITOA(DT/100),ITOA((DT%100)/10),
                                        ITOA((DT%100)%10),CR"
              SEND_STRING MDP,"LF,'21B',CR"
           }
           ACTIVE (FUNC = TRACK_ORDER) :
           {
              SEND_STRING MDP,"'0A24',D1,D2,D3,D4,CR"
              (* Where :
                   D1  : DATA1 (10,1)
                   D2  : DATA2 001-255
                   TRACK = (D2*100) + D1
                   D3  : TRAK ORDER (01-25)
                   D4  : PGM AREA (00-39)
              *)
           }
           ACTIVE (FUNC = CLEAR_PGM)   :
           {
              SEND_STRING MDP,"LF,'62CCCAA',CR"
           }
         }
      }
      ACTIVE (FUNC_TYPE = 2) :   (* Mode Setting *)
      {
         SELECT
         {
           ACTIVE (FUNC = AUTO_PAUSE) :
           {
              IF (DT = 1) (* AUTO_PAUSE_OFF *)
                   SEND_STRING MDP,"LF,'43000',CR"
              IF (DT = 2) (* AUTO_PAUSE_ON *)
                   SEND_STRING MDP,"LF,'43001',CR"
              IF (DT = 3) (* AUTO_CUE_ON *)
                   SEND_STRING MDP,"LF,'43002',CR"
              IF (DT = 4) (* AUTO_SENSE *)
                   SEND_STRING MDP,"LF,'430FF',CR"
           }
           ACTIVE (FUNC = EOM)        :
           {
             IF (DT = 1)  (* EOM MODE OFF *)
                   SEND_STRING MDP,"LF,'43200',CR"
             IF (DT = 2)  (* EOM MODE SENSE *)
                   SEND_STRING MDP,"LF,'432FF',CR"
           }
           ACTIVE (FUNC = AUTO_DISP):
           {
              SEND_STRING MDP,"LF,'431FF',CR"
           }
           ACTIVE (FUNC = PREVENT)    :
           {
              IF (DT = 1) (* DISABLE *)
                   SEND_STRING MDP,"LF,'44C00',CR"
              IF (DT = 2) (* ENABLE *)
                   SEND_STRING MDP,"LF,'44C01',CR"
              IF (DT = 3) (* SENSE *)
                   SEND_STRING MDP,"LF,'44CFF',CR"
           }
           ACTIVE (FUNC = PGM_MODE)    :
           {
             (* PGM AREA = '00'-'39' *)
             IF (DT = 1)  (* PGM SET *)
               SEND_STRING MDP,"LF,'62C00',PGM_AREA,CR"
             IF (DT = 2)  (* PGM SET PAUSE *)
               SEND_STRING MDP,"LF,'62C01',PGM_AREA,CR"
             IF (DT = 3)  (* PGM SET PLAY *)
               SEND_STRING MDP,"LF,'62C02',PGM_AREA,CR"
             IF (DT = 4)  (* PGM CLEAR *)
               SEND_STRING MDP,"LF,'62CCCAA',CR"
             IF (DT = 5)  (* PGM MODE RESET *)
               SEND_STRING MDP,"LF,'62CEE',PGM_AREA,CR"
             IF (DT = 6)  (* PGM MODE SENSE *)
               SEND_STRING MDP,"LF,'62CFF',PGM_AREA,CR"
           }
         }
      }
      ACTIVE (FUNC_TYPE = 3) :   (* Status Detect *)
      {
         SELECT
         {
            ACTIVE (FUNC = INFO_RETURN) :
               SEND_STRING MDP,"LF,'20F',CR"
            ACTIVE (FUNC = MECHA_STATUS) :
               SEND_STRING MDP,"LF,'250',CR"
            ACTIVE (FUNC = TRACK_NUM_STATUS) :
               SEND_STRING MDP,"LF,'255',CR"
            ACTIVE (FUNC = DISC_STATUS) :
               SEND_STRING MDP,"LF,'256',CR"
            ACTIVE (FUNC = DISC_NAME) :
               SEND_STRING MDP,"LF,'257',CR"
            ACTIVE (FUNC = TRACK_TIME):
               SEND_STRING MDP,"LF,'258',CR"
            ACTIVE (FUNC = TRACK_NAME):
            {
               SEND_STRING MDP,"LF,'45900',CR"
               SEND_STRING MDP,"LF,'45901',CR"
               SEND_STRING MDP,"LF,'45902',CR"
               SEND_STRING MDP,"LF,'45903',CR"
            }
            ACTIVE (FUNC = GET_TRACK_TIME):
               SEND_STRING MDP,"LF,'25C',CR"
         }
      }
      ACTIVE (FUNC_TYPE = 4) :   (* Time Information *)
      {
         SELECT
         {
            ACTIVE (FUNC = TOTAL_TIME) :
            {
               SEND_STRING MDP,"LF,'45E00',CR"
            }
         }
      }
      ACTIVE (FUNC_TYPE = 5) :   (* Character Information *)
      {
         SELECT
         {
            ACTIVE (FUNC = DISC_TITLE)   :
            {
               LEN = LENGTH_STRING(TITLE) + 4
               (* 00 : Start @ Char 1  *)
               (* 01 : Start @ Char 9  *)
               (* 02 : Start @ Char 17 *)
               (* ... *)
               (* 09 : Start @ Char 73 *)
               (* 0A : Start @ Char 81 *)
               (* 0B : Start @ Char 89 *)
               (* 0C : Start @ Char 97 *)
               SEND_STRING MDP,"LF,ITOHEX(LEN),'6700',TITLE,CR"
               SEND_STRING MDP,"LF,ITOHEX(LEN),'6701',TITLE,CR"
               SEND_STRING MDP,"LF,ITOHEX(LEN),'6702',TITLE,CR"
               SEND_STRING MDP,"LF,ITOHEX(LEN),'6703',TITLE,CR"
               SEND_STRING MDP,"LF,ITOHEX(LEN),'6704',TITLE,CR"
               SEND_STRING MDP,"LF,ITOHEX(LEN),'6705',TITLE,CR"
            }
         }
      }
      ACTIVE (FUNC_TYPE = 6) :   (* Editing Functions *)
      {
         SELECT
         {
            ACTIVE (FUNC = MDP_DIVIDE) :
            {
                (* DIVIDE_MODE = '00' OR '01' OR '02' OR '03' OR
                                 '04' OR '05' *)
                SEND_STRING MDP,"LF,'417',DIVIDE_MODE,CR"
            }
            ACTIVE (FUNC = MDP_COMBINE) :
            {
                (* COMBINE_MODE = '00' --> NO DATA2 & DATA3
                                = '01' --> START @ DATA2 & DATA3
                                TRACL = 3-DIGIT NUM
                                = '02' --> TRACKS COMBINED @ REHEARSED POS *)
               IF (COMBINE_MODE = '01') (* @ TRACK 123 : '0123'*)
                 SEND_STRING MDP,"LF,'8180123',CR"
               ELSE
               IF (COMBINE_MODE = '02') (* @ TRACK 23 : '0023' *)
                 SEND_STRING MDP,"LF,'8180023',CR"
               ELSE
                 SEND_STRING MDP,"LF,'41800',CR"
            }
            ACTIVE (FUNC = MDP_MOVE)    :
            {
               (* SEND_STRING MDP,"LF,'0A19',DATA1,DATA2,DATA3,DATA4,CR"
               DATA1 = (10,1)
               DATA2 = (001-255)
               - DATA1 + (DATA2*100) = DESTINATION TRACK
               DATA3 = (10,1)
               DATA4 = (001-255)
               - DATA3 + (DATA4*100) = SOURCE TRACK
               *)
            }
            ACTIVE (FUNC = TRACK_ERASE) :
            {
              SEND_STRING MDP,"LF,'41303',CR"
            }
            ACTIVE (FUNC = ALL_ERASE)   :
            {
              SEND_STRING MDP,"LF,'41304',CR"
            }
         }
      }
   }
}
DEFINE_CALL 'MDP1' (DECK,PANEL,PLAYB,STOPB,PAUSEB,FFWDB,REWB,
                    SFWDB,SREVB,FIRST)
LOCAL_VAR
  OFFSET_FN
  OFFSET_FB
  LAST_FN
{

   (* get offsets if any *)
   IF (FIRST BAND $00FF)
     OFFSET_FN=(FIRST BAND $00FF)-PLAY
   ELSE
     OFFSET_FN=0
   IF (FIRST BAND $FF00)
     OFFSET_FB=((FIRST BAND $FF00)/$FF)-PLAY_FB
   ELSE
     OFFSET_FB=0

   PUSH[PANEL,PLAYB]
   PUSH[PANEL,STOPB]
   PUSH[PANEL,PAUSEB]
   PUSH[PANEL,FFWDB]
   PUSH[PANEL,REWB]
   PUSH[PANEL,SFWDB]
   PUSH[PANEL,SREVB]
   {
   }

   PUSH[PANEL,PLAYB]
   {
      SEND_STRING DECK,"$0A,'211',$0D"
      SYSTEM_CALL 'FEEDBACK' (DECK,PLAY,FIRST)
   }
   PUSH[PANEL,STOPB]
   {
      SEND_STRING DECK,"$0A,'41000',$0D"
      SYSTEM_CALL 'FEEDBACK' (DECK,STOP,FIRST)
   }
   PUSH[PANEL,PAUSEB]
   {
      IF ([DECK,OFFSET_FB+PLAY_FB])
      {
        SEND_STRING DECK,"$0A,'41002',$0D"
        SYSTEM_CALL 'FEEDBACK' (DECK,PAUSE,FIRST)
      }
      ELSE IF ([DECK,OFFSET_FB+PAUSE_FB])
      {
        SEND_STRING DECK,"$0A,'211',$0D"
        SYSTEM_CALL 'FEEDBACK' (DECK,PLAY,FIRST)
      }
   }
   PUSH[PANEL,FFWDB]
   SELECT
   {
      ACTIVE ((SFWDB AND [DECK,OFFSET_FB+PLAY_FB]) OR
              [DECK,OFFSET_FB+STOP_FB]             OR
              [DECK,OFFSET_FB+PAUSE_FB]) :
      {
        SELECT
        {
           ACTIVE ([DECK,OFFSET_FB+PLAY_FB]) : LAST_FN = PLAY
           ACTIVE ([DECK,OFFSET_FB+STOP_FB]) : LAST_FN = STOP
           ACTIVE ([DECK,OFFSET_FB+PAUSE_FB]): LAST_FN = PAUSE
        }
        SEND_STRING DECK,"$0A,'41A00',$0D"
        SYSTEM_CALL 'FEEDBACK' (DECK,FFWD,FIRST)
      }
      ACTIVE (SFWDB = NO_BUTTON AND [DECK,OFFSET_FB+PLAY_FB]) :
      {
        SYSTEM_CALL 'FEEDBACK' (DECK,SFWD,FIRST)
      }
   }
   PUSH[PANEL,REWB]
   SELECT
   {
      ACTIVE ((SREVB AND [DECK,OFFSET_FB+PLAY_FB]) OR
              [DECK,OFFSET_FB+STOP_FB]             OR
              [DECK,OFFSET_FB+PAUSE_FB]) :
      {
        SELECT
        {
           ACTIVE ([DECK,OFFSET_FB+PLAY_FB]) : LAST_FN = PLAY
           ACTIVE ([DECK,OFFSET_FB+STOP_FB]) : LAST_FN = STOP
           ACTIVE ([DECK,OFFSET_FB+PAUSE_FB]): LAST_FN = PAUSE
        }
        SEND_STRING DECK,"$0A,'41A01',$0D"
        SYSTEM_CALL 'FEEDBACK' (DECK,REW,FIRST)
      }
      ACTIVE (SREVB = NO_BUTTON AND [DECK,OFFSET_FB+PLAY_FB]) :
      {
        SYSTEM_CALL 'FEEDBACK' (DECK,SREV,FIRST)
      }
   }

   PUSH[PANEL,SFWDB]
   IF (SFWDB AND [DECK,OFFSET_FB+PLAY_FB])
   {
     LAST_FN = PLAY
     SEND_STRING DECK,"$0A,'41602',$0D"
     SYSTEM_CALL 'FEEDBACK' (DECK,SFWD,FIRST)
   }
   PUSH[PANEL,SREVB]
   IF (SREVB AND [DECK,OFFSET_FB+PLAY_FB])
   {
     LAST_FN = PLAY
     SEND_STRING DECK,"$0A,'4160A',$0D"
     SYSTEM_CALL 'FEEDBACK' (DECK,SREV,FIRST)
   }

   RELEASE[PANEL,FFWDB]
   RELEASE[PANEL,REWB]
   IF (LAST_FN)
   {
     SYSTEM_CALL 'FEEDBACK' (DECK,LAST_FN,FIRST)
     LAST_FN = 0
   }
   RELEASE[PANEL,SFWDB]
   RELEASE[PANEL,SREVB]
   IF (LAST_FN)
   {
     IF (LAST_FN = PLAY)  SEND_STRING DECK,"$0A,'211',$0D"
     ELSE SEND_STRING DECK,"$0A,'41000',$0D"
     SYSTEM_CALL 'FEEDBACK' (DECK,LAST_FN,FIRST)
     LAST_FN = 0
   }

   IF (!MDP1_DEFEAT_FEEDBACK)
   {
     [PANEL,PLAYB]  = [DECK,OFFSET_FB+PLAY_FB]
     [PANEL,STOPB]  = [DECK,OFFSET_FB+STOP_FB]
     [PANEL,PAUSEB] = [DECK,OFFSET_FB+PAUSE_FB]
     [PANEL,FFWDB]  = [DECK,OFFSET_FB+FFWD_FB]
                      OR (SFWDB=NO_BUTTON
                      AND [DECK,OFFSET_FB+SFWD_FB])
     [PANEL,REWB]   = [DECK,OFFSET_FB+REW_FB]
                      OR (SREVB=NO_BUTTON
                      AND [DECK,OFFSET_FB+SREV_FB])
     [PANEL,SFWDB]  = [DECK,OFFSET_FB+SFWD_FB]
     [PANEL,SREVB]  = [DECK,OFFSET_FB+SREV_FB]
    }
}

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

CREATE_BUFFER MINI_DISC,MINI_DISC_BUFF


CALL 'Mini Disc Function' (MINI_DISC,3,INFO_RETURN,0)
CALL 'Mini Disc Function' (MINI_DISC,3,MECHA_STATUS,0)
CALL 'Mini Disc Function' (MINI_DISC,3,DISC_NAME,0)
CALL 'Mini Disc Function' (MINI_DISC,3,TRACK_NAME,0)
CALL 'Mini Disc Function' (MINI_DISC,3,TRACK_TIME,0)
(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

IF (LENGTH_STRING(MINI_DISC_BUFF))
{
    DATA = REMOVE_STRING(MINI_DISC_BUFF,"CR",1)
    IF (LENGTH_STRING(DATA) && DATA[1] = LF)
    {
        LINE_FEED = GET_BUFFER_CHAR(DATA)
        SET_LENGTH_STRING(DATA,LENGTH_STRING(DATA)-1)
        SEND_STRING 0,"DATA,10,13"
        CMD_LEN   = GET_BUFFER_CHAR(DATA) - $30
        CMD         = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
        SELECT
        {
           ACTIVE (CMD   = '72'       ) :  (* ILLEGAL SENSE REQUEST *)
           {
IF (DEBUG_MSG)
              SEND_STRING 0,"'Illegal Request',10,13"
           }
           ACTIVE (CMD = '74'       ) :  (* POWER ON STATUS *)
           {
IF (DEBUG_MSG)
              SEND_STRING 0,"'Power On',10,13"
           }
           ACTIVE (CMD = '76'       ) :  (* MODE CHANGE STATUS *)
           (* Mode Change Status *)
           {
              DATA1 = "DATA[1],DATA[2]"
              SELECT
              {
                 ACTIVE (DATA1 = '00') :
                    IF ((![MINI_DISC,246]) && (![MINI_DISC,247]))
                      CALL 'Mini Disc Function' (MINI_DISC,3,MECHA_STATUS,0)
                 ACTIVE (DATA1 = '03') :
                    IF ((![MINI_DISC,246]) && (![MINI_DISC,247]))
                      CALL 'Mini Disc Function' (MINI_DISC,3,TRACK_NUM_STATUS,0)
              }
           }
           ACTIVE (CMD = '78'       ) :  (* ERROR SENSE *)
           {
IF (DEBUG_MSG)
              SEND_STRING 0,"'Error Sense Request',10,13"
           }
           ACTIVE (CMD = '79'       ) :  (* CAUSTION SENSE *)
           {
IF (DEBUG_MSG)
              SEND_STRING 0,"'Caution Sense Request',10,13"
           }
           ACTIVE (CMD = '7A'       ) :  (* ERROR DATA CLEAR *)
           {
IF (DEBUG_MSG)
              SEND_STRING 0,"'Clear Error Data',10,13"
           }
           ACTIVE (CMD = '7B'       ) :  (* CAUTION DATA CLEAR *)
           {
IF (DEBUG_MSG)
              SEND_STRING 0,"'Clear Caution Data',10,13"
           }
           ACTIVE (CMD = '8F'       ) : (* INFORMATION REQUEST *)
           {
              DATA1 = "DATA[1],DATA[2]" (* DEVICE TYPE *)
              DATA2 = "DATA[3],DATA[4]" (* SOFTWARE VER *)
IF (DEBUG_MSG)
{
              IF (DATA1 = '22')       SEND_STRING 0,"'MDP,S-B5',10,13"
              ELSE IF (DATA1 = '23')  SEND_STRING 0,"'MDP,S-B6P',10,13"
              ELSE                    SEND_STRING 0,"'??',10,13"
              SEND_STRING 0,"'Software Ver ',DATA2[1],'.',DATA2[2],10,13"
              SEND_STRING 0,"'Info Return',10,13"
}
           }
           ACTIVE (CMD = 'A3'       ) : (* TRACK NO LOCATE POINT RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]"
              DATA2 = "DATA[3],DATA[4]" (* TRACK NO *)

IF (DEBUG_MSG)
              SEND_STRING 0,"'Track No. Locate Point',10,13"
           }
           ACTIVE (CMD = 'A4'       ) : (* PGM TRACK NO RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* TRACK NO (10,1) *)
              DATA2 = "DATA[3],DATA[4]" (* TRACK NO (001-255) *)
              DATA3 = "DATA[5],DATA[6]" (* TRACK ORDER (1-25) *)
              DATA4 = "DATA[7],DATA[8]" (* PGM AREA (00-39) *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'PGM Track No Return',10,13"
           }
           ACTIVE (CMD = 'A5'       ) : (* MUTLI ACCESS PRESET RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* (10,1) *)
              DATA2 = "DATA[3],DATA[4]" (* TRACK NO (001-255) *)
              DATA3 = "DATA[5],DATA[6]" (* SLOT NO (1-10) *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Multi Access Preset',10,13"
           }
           ACTIVE (CMD = 'A6'       ) : (* NEXT AMS RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* (10,1) *)
              DATA2 = "DATA[3],DATA[4]" (* TRACK NO (001-255) *)
              DATA3 = "DATA[5],DATA[6]" (* 00 : NEXT AMX OFF
                                           01 : NEXT AMS ON   *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Next AMS Return',10,13"
           }
           ACTIVE (CMD = 'AC'       ) : (* PGM MODE RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* 00 : PGM MODE OFF
                                           01 : PGM MODE ON *)
              DATA2 = "DATA[3],DATA[4]"
IF (DEBUG_MSG)
              SEND_STRING 0,"'PGM Mode Return',10,13"
           }
           ACTIVE (CMD = 'AD'       ) : (* MUTLI ACCESS SLOT RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* CURRENT SLOT BEING PLAYED *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Multi Access Slot',10,13"
           }
           ACTIVE (CMD = 'B0'       ) : (* AUTO PAUSE/AUTO CUE RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* 00 : AUTO PAUSE OFF
                                           01 : AUTO PAUSE OFF
                                           02 : AUTO CUE   OFF
                                           03 : AUTO CUE   ON *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Auto Pause,Auto Cue Return',10,13"
           }
           ACTIVE (CMD = 'B2'       ) : (* END OF MESSAGE (OEM) TIME RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* 00 : EOM MODE OFF
                                           01 : EOM RETURN *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'End Of Message Return',10,13"
           }
           ACTIVE (CMD = 'B4'       ) : (* TIMER PLAY RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* 00 : TIMER PLAY OFF
                                           01 : TIMER PLAY ON
                                           02 : TIMER PLAY RESUME PLAY
                                           03 : TIMER PLAY RESUME NEXT *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Timer Play Return',10,13"
           }
           ACTIVE (CMD = 'BA'       ) : (* PLAY MODE RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* '00' : CONTINUE
                                           '01' : SHUFFLE
                                           '02' : PROGRAM
                                           '03' : MULTI ACCESS *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Play Mode Return',10,13"
           }
           ACTIVE (CMD = 'BB'       ) : (* REPEAT MODE RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* 00 : REPEAT OFF
                                           01 : REPEAT ON *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Repeat Mode Return',10,13"
           }
           ACTIVE (CMD = 'BD'       ) : (* KILL LOCAL MODE RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* 00 : KILL ALMOST
                                           01 : KILL ALL *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Kill Local Mode Return',10,13"
           }
           ACTIVE (CMD = 'CC'       ) : (* SWITCH ENABLE RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* 00 : DISABLE
                                           01 : ENABLE *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Switch Enable Return',10,13"
           }
           ACTIVE (CMD = 'D0'       ) : (* MECHA STATUS RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]"
              SELECT
              {
                 ACTIVE (DATA1 = '01') : (* PLAY *)
                    SYSTEM_CALL 'FEEDBACK' (MINI_DISC,PLAY,0)
                 ACTIVE (DATA1 = '10') : (* PAUSE ON *)
                    SYSTEM_CALL 'FEEDBACK' (MINI_DISC,PAUSE,0)
                 ACTIVE (DATA1 = '12') : (* STOP *)
                    SYSTEM_CALL 'FEEDBACK' (MINI_DISC,STOP,0)
                 ACTIVE (DATA1 = '13') : (* EJECT *)
                 {
IF (DEBUG_MSG)
                    SEND_STRING 0,"'Disc Ejected',10,13"
                    SYSTEM_CALL 'FEEDBACK' (MINI_DISC,STOP,0)
                 }
                 ACTIVE (DATA1 = '14') : (* DISC OUT *)
                 {
IF (DEBUG_MSG)
                    SEND_STRING 0,"'Disc Out',10,13"
                    SYSTEM_CALL 'FEEDBACK' (MINI_DISC,STOP,0)
                 }
                 ACTIVE (DATA1 = '23') : (* CUE FWD (SFWD) *)
                 {
IF (DEBUG_MSG)
                    SEND_STRING 0,"'CUE FWD',10,13"
                    SYSTEM_CALL 'FEEDBACK' (MINI_DISC,SFWD,0)
                 }
                 ACTIVE (DATA1 = '2B') : (* CUE BACK (SREV) *)
                 {
IF (DEBUG_MSG)
                    SEND_STRING 0,"'CUE REV',10,13"
                    SYSTEM_CALL 'FEEDBACK' (MINI_DISC,SREV,0)
                 }
                 ACTIVE (DATA1 = '52') : (* TOC WRITING *)
IF (DEBUG_MSG)
                    SEND_STRING 0,"'TOC Writing',10,13"
                 ACTIVE (DATA1 = '80'):  (* REC STANDBY,REC PAUSAE *)
IF (DEBUG_MSG)
                    SEND_STRING 0,"'REC STANDBY,REC PAUSE',10,13"
              }
              CALL 'Mini Disc Function' (MINI_DISC,3,TRACK_NUM_STATUS,0)
IF (DEBUG_MSG)
              SEND_STRING 0,"'MECHA Status Return',10,13"
           }
           ACTIVE (CMD = 'D5'       ) : (* TRACK NUM STATUS RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* BIT0 : EOM STATUS *)
              DATA2 = "DATA[3],DATA[4]" (* (10,1) *)
              DATA3 = "DATA[5],DATA[6]" (* (000-255) *)
              CUR_TRACK = (ATOI("DATA3") * 100) + ATOI("DATA2")
              SEND_COMMAND TP,"'!T',2,ITOA(CUR_TRACK/100),ITOA((CUR_TRACK%100)/10),
                                     ITOA((CUR_TRACK%100)%10)"
              CALL 'Mini Disc Function' (MINI_DISC,3,TRACK_NAME,0)
              CALL 'Mini Disc Function' (MINI_DISC,3,TRACK_TIME,0)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Track No Status Return ',DATA2,10,13"
           }
           ACTIVE (CMD = 'D5'       ) : (* DISC STATUS RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* BIT4 REC PROTECT
                                           BIT3 PRE RECORDED DISC
                                           BIT0 DISC PRESENT *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Disc Status Return ',DATA2,10,13"
           }
           ACTIVE (CMD = 'D7'       ) : (* DISC NAME RETURN *)
           {
              IF (DATA[2] = '0')        (* 00 : 1-8  CHARS RETURNED *)
                 CUR_DISC_NAME = "DATA"
              ELSE
                                        (*
                                           01 : 9-16 CHARS RETURNED
                                           02 :17-24 CHARS RETURNED
                                           03 :25-32
                                           04 :33-40
                                           05 :41-48
                                           .
                                           .
                                           09 :73-80
                                           0A :81-88
                                           0B :89-92
                                           0C :93-100 *)
                                           (* 1st CHAR SET BY DATA1 *)
                 CUR_DISC_NAME = "CUR_DISC_NAME,DATA"
IF (DEBUG_MSG)
              SEND_STRING 0,"'Disc Name ',DISC_NAME,10,13"
           }
           ACTIVE (CMD = 'D8'       ) : (* CURRENT TRACK TIME RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* 00 : Output min/sec
                                           01 : Output min/sec/sub-sec *)
              DATA2 = "DATA[3],DATA[4]" (* Minute (0-74) *)
              DATA3 = "DATA[5],DATA[6]" (* Second (0-59) *)
              DATA4 = "DATA[7],DATA[8]" (* Sub-second (0-85) *)

IF (DEBUG_MSG)
              SEND_STRING 0,"'Current Track Time Return',10,13"
           }
           ACTIVE (CMD = 'D9'       ) : (* CURRENT TRACK NAME RETURN *)
           {
              SELECT
              {
                 ACTIVE (DATA[2] = '0') : (* CHARS 1 - 8  *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = '1') : (* CHARS 9 - 16 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = '2') : (* CHARS 17- 24 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = '3') : (* CHARS 25- 32 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = '4') : (* CHARS 33- 40 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = '5') : (* CHARS 41- 48 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = '6') : (* CHARS 49- 56 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = '7') : (* CHARS 57- 64 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = '8') : (* CHARS 65- 72 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = '9') : (* CHARS 73- 80 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = 'A') : (* CHARS 81- 88 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = 'B') : (* CHARS 89- 92 *)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
                 ACTIVE (DATA[2] = 'C') : (* CHARS 93- 100*)
                 {
                   CMD = "GET_BUFFER_CHAR(DATA),GET_BUFFER_CHAR(DATA)"
                   CUR_TRACK_NAME[CUR_TRACK] = "CUR_TRACK_NAME[CUR_TRACK],
                                                DATA"
                   SEND_COMMAND TP,"'!T',1,CUR_TRACK_NAME[CUR_TRACK]"
                 }
              }
IF (DEBUG_MSG)
              SEND_STRING 0,"'Track Name',10,13"
           }
           ACTIVE (CMD = 'DC'       ) : (* CURRENT TRACK REMAIN TIME RETUR*)
           {
              DATA1 = "DATA[1],DATA[2]" (* Minute *)
              DATA2 = "DATA[3],DATA[4]" (* Second *)
              CALL 'Mini Disc Function' (MINI_DISC,3,GET_TRACK_TIME,0)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Track Time',10,13"
           }
           ACTIVE (CMD = 'DD'       ) : (* TOTAL TRACK NUM TOTAL TIME *)
           {
              DATA1 = "DATA[1],DATA[2]" (* (10,1) TOTAL TRACK NUM *)
              DATA2 = "DATA[3],DATA[4]" (* (000-355) TOTAL TRACK NUM *)
              DATA3 = "DATA[5],DATA[6]" (* TOTAL TIME (MINUTE) *)
              DATA4 = "DATA[7],DATA[8]" (* TOTAL TIME (SECONDS) *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Track Total Time',10,13"
           }
           ACTIVE (CMD = 'DE'       ) : (* HOUR METER RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]" (* 00 : TOTAL OPERATION HOURS *)
              DATA2 = "DATA[3],DATA[4]" (* (10,1) *)
              DATA3 = "DATA[5],DATA[6]" (* (1000,100) *)
              DATA4 = "DATA[7],DATA[8]" (* **,10000 *)
IF (DEBUG_MSG)
              SEND_STRING 0,"'Hour Meter Return',10,13"
           }
           ACTIVE (CMD = 'F8'       ) : (* ERROR SENSE RETURN *)
           {
              DATA1 = "DATA[1],DATA[2]"
              DATA2 = "DATA[3],DATA[4]"
IF (DEBUG_MSG)
              SEND_STRING 0,"'Error Sense Return',10,13"
           }
           ACTIVE (CMD = 'F9'       ) :
           {
              DATA1 = "DATA[1],DATA[2]"
              DATA2 = "DATA[3],DATA[4]"
IF (DEBUG_MSG)
              SEND_STRING 0,"'Cauion Sense Return',10,13"
           }
        }
    }
    DATA = ''
}

CALL 'MDP1' (MINI_DISC,TP,1,2,3,4,5,6,7,0)


PUSH[TP,255]                       (* GENERAL *)
{
     SEND_STRING MINI_DISC,"LF,MINI_DISC_CMD,CR"
}
PUSH[TP,254]                       (* GET TRACK NAME (1st 24 chars) *)
{
     SEND_STRING MINI_DISC,"LF,'45900',CR"
     SEND_STRING MINI_DISC,"LF,'45901',CR"
     SEND_STRING MINI_DISC,"LF,'45902',CR"
}
PUSH[TP,253]                       (* GET DISC NAME (1st 24 chars) *)
{
     SEND_STRING MINI_DISC,"LF,'45700',CR"
     SEND_STRING MINI_DISC,"LF,'45701',CR"
     SEND_STRING MINI_DISC,"LF,'45702',CR"
}
PUSH[TP,252]                       (* Write Track Name *)
{

     IF (TRK <= 9)
       SEND_STRING MINI_DISC,"LF,'6230',ITOA(TRK),'00',CR"
     SEND_STRING MINI_DISC,"LF,'21B',CR"
     STR ="'Track #',ITOA(TRK)"    (* Chars 1-8 *)
     WAIT 1
       SEND_STRING MINI_DISC,"LF,ITOHEX(LENGTH_STRING(STR)+4)'6900',STR,CR"
}
PUSH[TP,251]                       (* Write Disc  Name *)
{
     (* Name the Disc : AMX01,SONY Mini Disc Player MDS - BSP *)
     STR = 'AMX01,SO'
     STR_LEN = ITOHEX(LENGTH_STRING(STR) + 4)
     SEND_STRING MINI_DISC,"LF,STR_LEN,'6700',STR,CR"
     WAIT 30
     {
       STR = 'NY Mini '
       STR_LEN = ITOHEX(LENGTH_STRING(STR) + 4)
       SEND_STRING MINI_DISC,"LF,STR_LEN,'6701',STR,CR"
       WAIT 30
       {
         STR = 'Disc Pla'
         STR_LEN = ITOHEX(LENGTH_STRING(STR) + 4)
         SEND_STRING MINI_DISC,"LF,STR_LEN,'6702',STR,CR"
         WAIT 30
         {
           STR = 'yer MDS '
           STR_LEN = ITOHEX(LENGTH_STRING(STR) + 4)
           SEND_STRING MINI_DISC,"LF,STR_LEN,'6703',STR,CR"
           WAIT 30
           {
               STR = '- BSP'
               STR_LEN = ITOHEX(LENGTH_STRING(STR) + 4)
               SEND_STRING MINI_DISC,"LF,STR_LEN,'6704',STR,CR"
           }
         }
       }
     }
}
PUSH[TP,250]                       (* TEST *)
{
     SEND_STRING MINI_DISC,"LF,MINI_DISC_CMD,CR"
}
(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

